@@ -72,7 +72,10 @@ def handle_call_schedulemanager():
 def handle_check_deployment():
     function_name, project_name = sys.argv[2].split("@")
     client = cdf.experimental_client(project_name)
-    cdf_model_version = client.assets.retrieve(external_id=function_name).metadata["modelVersion"]
+    model_asset = client.assets.retrieve(external_id=function_name)
+    if model_asset is None:
+        return str(True)
+    cdf_model_version = model_asset.metadata["modelVersion"]
     configuration = get_master_config()[1][project_name]
     key1 = [i for i in configuration.keys() if i.parts[-1] == function_name][0]
     model_version = configuration[key1].model_version
